@@ -2,6 +2,7 @@ mod config;
 #[cfg(test)]
 mod test;
 use std::collections::HashMap;
+use std::path::{Path, PathBuf};
 use std::sync::{Arc, LazyLock, RwLock};
 
 use tokio::sync::Mutex;
@@ -17,10 +18,10 @@ use crate::fileapi::DEFAULT_QUERY;
 use crate::formatting::getformat;
 use crate::gammar::{checkerror, ErrorInformation, LintConfigInfo};
 use crate::semantic_token::LEGEND_TYPE;
-use crate::utils::{did_vcpkg_project, treehelper, VCPKG_LIBS, VCPKG_PREFIX};
+use crate::utils::{did_vcpkg_project, treehelper, DocumentNormalize, VCPKG_LIBS, VCPKG_PREFIX};
 use crate::{
     ast, complete, document_link, fileapi, filewatcher, hover, jump, scansubs, semantic_token,
-    utils,
+    utils, BackendInitInfo,
 };
 
 pub static BUFFERS_CACHE: LazyLock<Arc<Mutex<HashMap<lsp_types::Url, String>>>> =
@@ -50,19 +51,30 @@ pub fn client_support_snippet() -> bool {
 }
 
 impl Backend {
-    async fn path_in_project(&self, path: &str) -> bool {
-        if self.root_path.lock().await.is_none() {
-            return true;
-        }
-
-        // NOTE: not enough good, but is ok
-        !path.starts_with("/usr")
+    fn root_path(&self) -> Option<&PathBuf> {
+        self.root_path.get_or_init(|| None).as_ref()
     }
-    async fn publish_diagnostics(&self, uri: Url, context: String, lint_info: LintConfigInfo) {
-        if !self.path_in_project(uri.path()).await {
-            return;
-        }
 
+    fn init_info(&self) -> &BackendInitInfo {
+        self.init_info
+            .get()
+            .expect("Should have been inited before")
+    }
+
+    async fn path_in_project<P: AsRef<Path>>(&self, path: P) -> bool {
+        let Some(root_path) = self.root_path() else {
+            return true;
+        };
+
+        let Some(diff) = pathdiff::diff_paths(path, root_path) else {
+            return false;
+        };
+        use std::path::Component;
+        diff.components()
+            .all(|component| component != Component::ParentDir)
+    }
+
+    async fn publish_diagnostics(&self, uri: Url, context: String, lint_info: LintConfigInfo) {
         let Ok(file_path) = uri.to_file_path() else {
             tracing::error!("Cannot transport {uri:?} to file_path");
             self.client
@@ -74,6 +86,10 @@ impl Backend {
             return;
         };
 
+        if !self.path_in_project(&file_path).await {
+            return;
+        }
+
         let gammererror = checkerror(&file_path, &context, lint_info);
         if let Some(diagnoses) = gammererror {
             let mut pusheddiagnoses = vec![];
@@ -119,7 +135,7 @@ impl Backend {
                 uri.clone(),
                 context.to_string(),
                 LintConfigInfo {
-                    use_lint: self.init_info.lock().await.enable_lint,
+                    use_lint: self.init_info().enable_lint,
                     use_extra_cmake_lint: true,
                 },
             )
@@ -138,13 +154,16 @@ impl LanguageServer for Backend {
 
         let do_format = initial_config.is_format_enabled();
 
-        let find_cmake_in_package = initial_config.is_scan_cmake_in_package();
+        let scan_cmake_in_package = initial_config.is_scan_cmake_in_package();
 
-        let lint_enable = initial_config.is_lint_enabled();
+        let enable_lint = initial_config.is_lint_enabled();
 
-        let mut init_info = self.init_info.lock().await;
-        init_info.scan_cmake_in_package = find_cmake_in_package;
-        init_info.enable_lint = lint_enable;
+        self.init_info
+            .set(BackendInitInfo {
+                scan_cmake_in_package,
+                enable_lint,
+            })
+            .expect("here should be the first place to init the init_info");
 
         if let Some(workspace) = initial.capabilities.workspace {
             if let Some(watch_file) = workspace.did_change_watched_files {
@@ -203,8 +222,9 @@ impl LanguageServer for Backend {
             .and_then(|folders| folders.first())
             .and_then(|folder| folder.uri.to_file_path().ok())
         {
-            let mut root_path = self.root_path.lock().await;
-            root_path.replace(project_root.to_path_buf());
+            self.root_path
+                .set(Some(project_root.to_path_buf()))
+                .expect("here should be the only place to set the root_path");
         }
 
         set_client_text_document(initial.capabilities.text_document);
@@ -321,9 +341,8 @@ impl LanguageServer for Backend {
         self.client
             .log_message(MessageType::INFO, "initialized!")
             .await;
-        let root_path_lock = self.root_path.lock().await;
-        let root_path = root_path_lock.clone();
-        drop(root_path_lock);
+        let root_path_lock = self.root_path();
+        let root_path = root_path_lock;
         let work_done_token = ProgressToken::Number(1);
         let progress = self
             .client
@@ -437,7 +456,7 @@ impl LanguageServer for Backend {
             if file_name.ends_with("txt") {
                 has_cached_changed = true;
                 if file_name == "CMakeLists.txt" {
-                    let Some(ref path) = *self.root_path.lock().await else {
+                    let Some(path) = self.root_path() else {
                         continue;
                     };
                     scansubs::scan_all(path, false).await;
@@ -465,7 +484,7 @@ impl LanguageServer for Backend {
         let mut parse = Parser::new();
         parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
         let uri = input.text_document.uri.clone();
-        let context = input.text_document.text.clone();
+        let context = input.text_document.text.normalize();
         let mut storemap = BUFFERS_CACHE.lock().await;
         storemap.entry(uri.clone()).or_insert(context.clone());
         drop(storemap);
@@ -484,11 +503,12 @@ impl LanguageServer for Backend {
             uri,
             context,
             LintConfigInfo {
-                use_lint: self.init_info.lock().await.enable_lint,
+                use_lint: self.init_info().enable_lint,
                 use_extra_cmake_lint: true,
             },
         )
         .await;
+
         self.client
             .log_message(MessageType::INFO, "file opened!")
             .await;
@@ -497,7 +517,7 @@ impl LanguageServer for Backend {
     async fn did_change(&self, input: DidChangeTextDocumentParams) {
         // create a parse
         let uri = input.text_document.uri.clone();
-        let context = input.content_changes[0].text.clone();
+        let context = input.content_changes[0].text.normalize();
         let mut storemap = BUFFERS_CACHE.lock().await;
         storemap.insert(uri.clone(), context.clone());
         drop(storemap);
@@ -506,7 +526,7 @@ impl LanguageServer for Backend {
                 uri,
                 context,
                 LintConfigInfo {
-                    use_lint: self.init_info.lock().await.enable_lint,
+                    use_lint: self.init_info().enable_lint,
                     use_extra_cmake_lint: false,
                 },
             )
@@ -521,7 +541,7 @@ impl LanguageServer for Backend {
         let uri = params.text_document.uri;
         let storemap = BUFFERS_CACHE.lock().await;
 
-        let has_root = self.root_path.lock().await.is_some();
+        let has_root = self.root_path().is_some();
         let Some(context) = storemap.get(&uri).cloned() else {
             self.client
                 .log_message(MessageType::INFO, "file saved!")
@@ -545,7 +565,7 @@ impl LanguageServer for Backend {
             uri,
             context.to_string(),
             LintConfigInfo {
-                use_lint: self.init_info.lock().await.enable_lint,
+                use_lint: self.init_info().enable_lint,
                 use_extra_cmake_lint: true,
             },
         )
@@ -616,8 +636,8 @@ impl LanguageServer for Backend {
                 format!("file {:?} closed!", params.text_document.uri),
             )
             .await;
-        //notify_send("file closed", Type::Info);
     }
+
     async fn completion(&self, input: CompletionParams) -> Result<Option<CompletionResponse>> {
         self.client.log_message(MessageType::INFO, "Complete").await;
         let location = input.text_document_position.position;
@@ -638,7 +658,7 @@ impl LanguageServer for Backend {
                 location,
                 &self.client,
                 &file_path,
-                self.init_info.lock().await.scan_cmake_in_package,
+                self.init_info().scan_cmake_in_package,
             )
             .await),
             None => Ok(None),
